==> pkg_add_it-1.0.tar.gz: pkg_add_it-1.0/fnode.h <==
/*-
 * Copyright (c) 2008  Marin Atanasov  <dnaeon@gmail.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */


# ifndef __fnode_h_
# define __fnode_h_

/* defines fnode_t type */
typedef struct fnode {
   char *fname;         /* package name            */
   char *fpath;         /* package path/category   */
   char *desc;          /* package description     */
   char *maint;         /* package maintainer      */
   struct fnode *next;  /* next node               */
} fnode_t;

/* define functions parameters as macros */
# define FNODEPUSHARGS     fnode_t **head, const char *fname, const char *fpath, const char *desc, const char *maint
# define FNODEDISPLAYARGS  fnode_t *head, int numfiles
# define FNODELOCATEARGS   fnode_t *head, int index, fnode_t **pkgfile
# define FNODESHUTDOWNARGS fnode_t *head

/* settings for a default pager */
# define MAXLINESPERPAGE   50
# define DEFAULTPAGER      "less"
# define PAGERTMPFILE      "/tmp/pkg_add_it.tmp"

# define LONGLINE          "#####################################################################\n"

/* saves a matched record in a stack
 * this function is used only by scan_directory() and scan_index_file ()
 */
void fnode_push (FNODEPUSHARGS);

/* displays all found patterns */
int fnode_display (FNODEDISPLAYARGS); 

/* locates a pattern with an index number and copies its information in `pkgfile' */
void fnode_locate (FNODELOCATEARGS);

/* deallocates the fnode_t stack */
void fnode_shutdown (FNODESHUTDOWNARGS);

# endif /* ! ifndef __fnode_h_ ! */

==> pkg_add_it-1.1.tar.gz: pkg_add_it-1.1/fnode.h <==
/*-
 * Copyright (c) 2008  Marin Atanasov  <dnaeon@gmail.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */


# ifndef __fnode_h_
# define __fnode_h_

/* defines fnode_t type */
typedef struct fnode {
   char *fname;         /* package name            */
   char *fpath;         /* package path/category   */
   char *desc;          /* package description     */
   char *maint;         /* package maintainer      */
   struct fnode *next;  /* next node               */
} fnode_t;

/* define functions parameters as macros */
# define FNODEPUSHARGS        fnode_t **head, const char *fname, const char *fpath, const char *desc, const char *maint
# define FNODEDISPLAYARGS     fnode_t *head, int numfiles
# define FNODECHOOSEPKGARGS   int numfiles
# define FNODELOCATEARGS      fnode_t *head, int index, fnode_t **pkgfile
# define FNODESHUTDOWNARGS    fnode_t *head

/* settings for a default pager */
# define MAXLINESPERPAGE   50
# define DEFAULTPAGER      "less"
# define PAGERTMPFILE      "/tmp/pkg_add_it.tmp"

# define LONGLINE          "#####################################################################\n"

/* saves a matched record in a stack
 * this function is used only by scan_directory() and scan_index_file ()
 */
void fnode_push (FNODEPUSHARGS);

/* displays all found patterns */
void fnode_display (FNODEDISPLAYARGS); 

/* asks the user to choose a package */
int fnode_choose_pkg (FNODECHOOSEPKGARGS);

/* locates a pattern with an index number and copies its information in `pkgfile' */
void fnode_locate (FNODELOCATEARGS);

/* deallocates the fnode_t stack */
void fnode_shutdown (FNODESHUTDOWNARGS);

# endif /* ! ifndef __fnode_h_ ! */
